@@ -2,8 +2,8 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
- * by the Free Software Foundation.                                  *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
+ * 2008, 2009 and 2010 by the Free Software Foundation.              *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -1143,8 +1143,14 @@ play_aftermath(int color, SGFTree *aftermath_sgftree)
 	a->final_status[pos] = ALIVE;
     }
     else {
-      if (board[pos] == EMPTY)
+      if (board[pos] == EMPTY) {
+	int enclosing_color = examine_cavity(pos, NULL);
 	a->final_status[pos] = DAME;
+	if (enclosing_color == BLACK)
+	  a->black_area++;
+	else if (enclosing_color == WHITE)
+	  a->white_area++;
+      }
       else {
 	a->final_status[pos] = ALIVE_IN_SEKI;
 	if (board[pos] == WHITE)
