@@ -3,7 +3,7 @@
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
  * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
- * 2008 and 2009 by the Free Software Foundation.                    *
+ * 2008, 2009 and 2010 by the Free Software Foundation.              *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -1040,6 +1040,9 @@ dragon_looks_inessential(int origin)
   if (dragon[origin].size != worm[origin].size)
     return 0;
 
+  if (worm[origin].size >= 3 && worm[origin].liberties >= 4)
+    return 0;
+
   if (owl_substantial(origin))
     return 0;
 
