@@ -3,7 +3,7 @@
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
  * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
- * 2008 and 2009 by the Free Software Foundation.                    *
+ * 2008, 2009 and 2010 by the Free Software Foundation.              *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -937,9 +937,6 @@ void
 influence_erase_territory(struct influence_data *q, int pos, int color)
 {
   int k;
-  ASSERT1((color == WHITE && q->territory_value[pos] >= 0.0)
-          || (color == BLACK && q->territory_value[pos] <= 0.0), pos);
-
   current_influence = q;
 
   q->territory_value[pos] = 0.0;
