@@ -3,7 +3,7 @@
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
  * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
- * 2008 and 2009 by the Free Software Foundation.                    *
+ * 2008, 2009 and 2010 by the Free Software Foundation.              *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -115,6 +115,13 @@ compute_surroundings(int pos, int apos, int showboard, int *surround_size)
   memset(mf, 0, sizeof(mf));
   memset(mn, 0, sizeof(mn));
   memset(sd, 0, sizeof(sd));
+
+  /* These should not be strictly necessary to clear but doing so
+   * avoids compiler warnings about possibly using uninitialized
+   * variables.
+   */
+  memset(left_corner, 0, sizeof(left_corner));
+  memset(right_corner, 0, sizeof(right_corner));
   
   mark_dragon(pos, mf, 1);
 
