@@ -2,8 +2,8 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
- * by the Free Software Foundation.                                  *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
+ * 2008, 2009 and 2010 by the Free Software Foundation.              *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -44,7 +44,6 @@ static void change_tactical_point(int str, int move, int code,
 static void propagate_worm2(int str);
 static int genus(int str);
 static void markcomponent(int str, int pos, int mg[BOARDMAX]);
-static int examine_cavity(int pos, int *edge);
 static void cavity_recurse(int pos, int mx[BOARDMAX], 
 			   int *border_color, int *edge, int str);
 static void ping_cave(int str, int *result1,  int *result2,
@@ -1233,6 +1232,7 @@ propagate_worm2(int str)
 
 /* Report all known attack, defense, attack threat, and defense threat
  * moves. But limit this to the moves which can be made by (color).
+ * Exclude send-two-return-one moves.
  */
 void
 worm_reasons(int color)
@@ -1249,10 +1249,12 @@ worm_reasons(int color)
 
     if (board[pos] == OTHER_COLOR(color)) {
       for (k = 0; k < MAX_TACTICAL_POINTS; k++) {
-	if (worm[pos].attack_codes[k] != 0)
+	if (worm[pos].attack_codes[k] != 0
+	    && !send_two_return_one(worm[pos].attack_points[k], color))
 	  add_attack_move(worm[pos].attack_points[k], pos,
 			  worm[pos].attack_codes[k]);
-	if (worm[pos].attack_threat_codes[k] != 0)
+	if (worm[pos].attack_threat_codes[k] != 0
+	    && !send_two_return_one(worm[pos].attack_threat_points[k], color))
 	  add_attack_threat_move(worm[pos].attack_threat_points[k], pos,
 				 worm[pos].attack_threat_codes[k]);
       }
@@ -1260,11 +1262,14 @@ worm_reasons(int color)
       
     if (board[pos] == color) {
       for (k = 0; k < MAX_TACTICAL_POINTS; k++) {
-	if (worm[pos].defense_codes[k] != 0)
+	if (worm[pos].defense_codes[k] != 0
+	    && !send_two_return_one(worm[pos].defense_points[k], color))
 	  add_defense_move(worm[pos].defense_points[k], pos,
 			   worm[pos].defense_codes[k]);
 
-	if (worm[pos].defense_threat_codes[k] != 0)
+	if (worm[pos].defense_threat_codes[k] != 0
+	    && !send_two_return_one(worm[pos].defense_threat_points[k],
+				    color))
 	  add_defense_threat_move(worm[pos].defense_threat_points[k], pos,
 				  worm[pos].defense_threat_codes[k]);
       }
@@ -1454,7 +1459,7 @@ markcomponent(int str, int pos, int mg[BOARDMAX])
  * edge in a point outside the removed string.  
  */
 
-static int
+int
 examine_cavity(int pos, int *edge)
 {
   int border_color = EMPTY;
@@ -1462,11 +1467,11 @@ examine_cavity(int pos, int *edge)
   int origin = NO_MOVE;
   
   ASSERT_ON_BOARD1(pos);
-  gg_assert(edge != NULL);
   
   memset(ml, 0, sizeof(ml));
 
-  *edge = 0;
+  if (edge)
+    *edge = 0;
 
   if (IS_STONE(board[pos]))
     origin = find_origin(pos);
@@ -1518,7 +1523,7 @@ cavity_recurse(int pos, int mx[BOARDMAX],
 
   mx[pos] = 1;
 
-  if (is_edge_vertex(pos) && board[pos] == EMPTY) 
+  if (edge && is_edge_vertex(pos) && board[pos] == EMPTY)
     (*edge)++;
 
   /* Loop over the four neighbors. */
