@@ -2,8 +2,8 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
- * by the Free Software Foundation.                                  *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
+ * 2008, 2009 and 2010 by the Free Software Foundation.              *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -411,7 +411,7 @@ static struct autohelper_func autohelper_functions[] = {
 		"connect_and_cut_helper2(%s, %s, %s, color)"},
   {"connect_and_cut_helper",	3, 0, 3.00, "connect_and_cut_helper(%s, %s, %s)"},
   {"owl_threatens",		2, 0, 0.01, "owl_threatens_attack(%s, %s)"},
-  {"replace",			2, 0, 0.0,  "add_replacement_move(%s, %s)"},
+  {"replace",			2, 0, 0.0,  "add_replacement_move(%s, %s, color)"},
   {"backfill_replace",		2, 0, 0.0,  "backfill_replace(%s, %s)"},
   {"non_oterritory",		1, 0, 0.0,
 		"influence_mark_non_territory(%s, color)"},
@@ -457,8 +457,8 @@ dummyhelper(int transformation, int move, int color, int action)
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *\n\
  * http://www.gnu.org/software/gnugo/ for more information.          *\n\
  *                                                                   *\n\
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *\n\
- * by the Free Software Foundation.                                  *\n\
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *\n\
+ * 2008 and 2009 by the Free Software Foundation.                    *\n\
  *                                                                   *\n\
  * This program is free software; you can redistribute it and/or     *\n\
  * modify it under the terms of the GNU General Public License as    *\n\
