@@ -3,7 +3,7 @@
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
  * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
- * 2008 and 2009 by the Free Software Foundation.                    *
+ * 2008, 2009 and 2010 by the Free Software Foundation.              *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -150,21 +150,77 @@ write_pattern(char *name, char board[MAX_BOARD + 2][MAX_BOARD + 2],
 }
 
 
+/* If cross-compiling to a platform with a different number of bits in
+ * a long, hashvalues generated by uncompress_fuseki need to be
+ * adapted to the target platform. Set CROSS_COMPILING to 1 and
+ * TARGET_SIZEOF_LONG to 4 for a 32-bit target or to 8 for a 64-bit
+ * target. For extremely exotic platforms TARGET_CHAR_BIT may need to
+ * be adjusted as well as TARGET_SIZEOF_LONG.
+ *
+ * FIXME: Even better, arrange so the configure magic can fill in
+ * these values.
+ */
+#define CROSS_COMPILING    0
+#define TARGET_SIZEOF_LONG 4
+#define TARGET_CHAR_BIT    8
+
+static void
+write_hash_value(Hash_data *pattern_hash)
+{
+  if (!CROSS_COMPILING
+      || (SIZEOF_LONG == TARGET_SIZEOF_LONG
+	  && CHAR_BIT == TARGET_CHAR_BIT)) {
+    int k;
+    for (k = 0; k < NUM_HASHVALUES; k++) {
+      printf("0x%lx", pattern_hash->hashval[k]);
+      if (k < NUM_HASHVALUES - 1)
+	printf(",");
+    }
+  }
+  else {
+    int k;
+    int j = 0;
+    int bits_in_hashvalue = CHAR_BIT * SIZEOF_LONG;
+    int bits_in_target_hashvalue = TARGET_CHAR_BIT * TARGET_SIZEOF_LONG;
+    Hashvalue h = 0;
+    int available_source_bits = 0;
+    unsigned int target_bits = 0;
+    int remaining_target_bits_in_current_hashvalue = bits_in_target_hashvalue;
+    printf("0x");
+    for (k = 0; k < NUM_HASHBITS
+	        || remaining_target_bits_in_current_hashvalue > 0; k++) {
+      if (available_source_bits == 0 && k < NUM_HASHBITS) {
+	h = pattern_hash->hashval[j++];
+	available_source_bits = bits_in_hashvalue;
+      }
+      available_source_bits--;
+      target_bits <<= 1;
+      if (k < NUM_HASHBITS)
+	target_bits |= (h >> available_source_bits) & 1;
+      remaining_target_bits_in_current_hashvalue--;
+      if (remaining_target_bits_in_current_hashvalue % 4 == 0) {
+	printf("%x", target_bits);
+	target_bits = 0;
+      }
+      if (remaining_target_bits_in_current_hashvalue == 0
+	  && k < NUM_HASHBITS - 1) {
+	printf(",0x");
+	remaining_target_bits_in_current_hashvalue = bits_in_target_hashvalue;
+      }
+    }
+  }
+}
+
 static void
 write_pattern_c_code(char *name, Intersection board1d[BOARDSIZE],
 		     int move_pos, int value, int boardsize, int patlen)
 {
-  int k;
   Hash_data pattern_hash;
 
   /* Compute hash. */
   hashdata_recalc(&pattern_hash, board1d, NO_MOVE);
   printf("  {{{");
-  for (k = 0; k < NUM_HASHVALUES; k++) {
-    printf("0x%lx", pattern_hash.hashval[k]);
-    if (k < NUM_HASHVALUES - 1)
-      printf(",");
-  }
+  write_hash_value(&pattern_hash);
   if (name)
     printf("}},%d,\"%s\",%d,%d},\n", patlen, name,
 	   OFFSET(I(move_pos) - (boardsize-1)/2,
@@ -175,7 +231,6 @@ write_pattern_c_code(char *name, Intersection board1d[BOARDSIZE],
 }
 
 
-
 #define DB_OUTPUT 	1
 #define C_OUTPUT 	2
 
